@@ -1,24 +1,12 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2012-2017 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0+
  */
 
+#pragma once
 
 /**
  * SECTION:gs-plugin-vfuncs
@@ -28,9 +16,6 @@
  * @short_description: Vfuncs that plugins can implement
  */
 
-#ifndef __GS_PLUGIN_VFUNCS_H
-#define __GS_PLUGIN_VFUNCS_H
-
 #include <appstream-glib.h>
 #include <glib-object.h>
 #include <gmodule.h>
@@ -40,7 +25,6 @@
 #include "gs-app.h"
 #include "gs-app-list.h"
 #include "gs-category.h"
-#include "gs-price.h"
 
 G_BEGIN_DECLS
 
@@ -426,9 +410,8 @@ gboolean	 gs_plugin_add_unvoted_reviews		(GsPlugin	*plugin,
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
- * Adds required information to a list of #GsApp's.
- * This function is only really required when "batching up" requests, and most
- * plugins are better using the per-app gs_plugin_refine_app() function.
+ * Adds required information to a list of #GsApp's. It allows requests to be
+ * batched up, which allows better performance than individual calls per app.
  *
  * An example for when this is useful would be in the PackageKit plugin where
  * we want to do one transaction of GetDetails with multiple source-ids rather
@@ -442,34 +425,6 @@ gboolean	 gs_plugin_refine			(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
-/**
- * gs_plugin_refine_app:
- * @plugin: a #GsPlugin
- * @app: a #GsApp
- * @flags: a #GsPluginRefineFlags, e.g. %GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Adds required information to @app.
- *
- * The general idea for @flags is that this indicates what the UI needs at the
- * moment. This doesn't mean you can't add more information if you have it,
- * for example, if we requested %GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE and had
- * to do some IO to get a blob of data, we can use gs_app_set_license() *and*
- * gs_app_set_origin() even though only the first thing was specified.
- *
- * If the plugin can't handle applications of the specific kind, or if the
- * plugin knows not of the #GsApp ID then it should just ignore the request and
- * return FALSE.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_refine_app			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GsPluginRefineFlags flags,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
 /**
  * gs_plugin_refine_wildcard:
  * @plugin: a #GsPlugin
@@ -562,27 +517,6 @@ gboolean	 gs_plugin_update_cancel		(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
-/**
- * gs_plugin_app_purchase:
- * @plugin: a #GsPlugin
- * @app: a #GsApp
- * @price: a #GsPrice
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Purchase the application.
- *
- * NOTE: Once the action is complete, the plugin must set the new state of @app
- * to %AS_APP_STATE_AVAILABLE.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_app_purchase			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GsPrice	*price,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
 /**
  * gs_plugin_app_install:
  * @plugin: a #GsPlugin
@@ -702,6 +636,11 @@ gboolean	 gs_plugin_update_app			(GsPlugin	*plugin,
  * Downloads the application and any dependencies ready to be installed or
  * updated.
  *
+ * Plugins are expected to schedule downloads using the system download
+ * scheduler if appropriate (if the download is not guaranteed to be under a few
+ * hundred kilobytes, for example), so that the user’s metered data preferences
+ * are honoured.
+ *
  * Plugins are expected to send progress notifications to the UI using
  * gs_app_set_progress() using the passed in @app.
  *
@@ -730,6 +669,11 @@ gboolean	 gs_plugin_download_app			(GsPlugin	*plugin,
  *
  * Downloads a list of applications ready to be installed or updated.
  *
+ * Plugins are expected to schedule downloads using the system download
+ * scheduler if appropriate (if the download is not guaranteed to be under a few
+ * hundred kilobytes, for example), so that the user’s metered data preferences
+ * are honoured.
+ *
  * Returns: %TRUE for success or if not relevant
  **/
 gboolean	 gs_plugin_download			(GsPlugin	*plugin,
@@ -923,7 +867,7 @@ gboolean	 gs_plugin_refresh			(GsPlugin	*plugin,
  * list. If no plugins can handle the file, the list will be empty.
  *
  * For example, the PackageKit plugin can turn a .rpm file into a application
- * of kind %AS_APP_KIND_UNKNOWN but that in some cases it will be futher refined
+ * of kind %AS_APP_KIND_UNKNOWN but that in some cases it will be further refined
  * into a %AS_APP_KIND_DESKTOP (with all the extra metadata) by the appstream
  * plugin.
  *
@@ -977,8 +921,22 @@ gboolean	 gs_plugin_update			(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
+/**
+ * gs_plugin_add_langpacks:
+ * @plugin: a #GsPlugin
+ * @list: a #GsAppList
+ * @locale: a #LANGUAGE_CODE or #LOCALE, e.g. "ja" or "ja_JP"
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Returns a list of language packs, as per input language code or locale.
+ *
+ * Returns: %TRUE for success or if not relevant
+ **/
+gboolean	 gs_plugin_add_langpacks		(GsPlugin	*plugin,
+							 GsAppList	*list,
+							 const gchar    *locale,
+							 GCancellable	*cancellable,
+							 GError		**error);
+
 G_END_DECLS
-
-#endif /* __GS_PLUGIN_VFUNCS_H */
-
-/* vim: set noexpandtab: */
