@@ -1,7 +1,8 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2013-2016 Richard Hughes <richard@hughsie.com>
- * Copyright (C) 2014-2018 Kalev Lember <klember@redhat.com>
+ * Copyright (C) 2014-2020 Kalev Lember <klember@redhat.com>
  *
  * SPDX-License-Identifier: GPL-2.0+
  */
@@ -87,6 +88,7 @@ enum {
 	SIGNAL_RELOAD,
 	SIGNAL_REPORT_EVENT,
 	SIGNAL_ALLOW_UPDATES,
+	SIGNAL_BASIC_AUTH_START,
 	SIGNAL_LAST
 };
 
@@ -531,9 +533,18 @@ gs_plugin_set_priority (GsPlugin *plugin, guint priority)
  * gs_plugin_get_locale:
  * @plugin: a #GsPlugin
  *
- * Gets the user locale.
+ * Gets the user locale. This is in the form documented in `man 3 setlocale`:
+ * ```
+ * language[_territory][.codeset][@modifier]
+ * ```
+ * where `language` is an
+ * [ISO 639 language code](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes),
+ * `territory` is an
+ * [ISO 3166 country code](https://en.wikipedia.org/wiki/ISO_3166-1), and
+ * `codeset` is a character set or encoding identifier like `ISO-8859-1` or
+ * `UTF-8`. For a list of all supported locales, run `locale -a`.
  *
- * Returns: the locale string, e.g. "en_GB"
+ * Returns: the locale string, e.g. `en_GB` or `uz_UZ.utf8@cyrillic`
  *
  * Since: 3.22
  **/
@@ -548,9 +559,13 @@ gs_plugin_get_locale (GsPlugin *plugin)
  * gs_plugin_get_language:
  * @plugin: a #GsPlugin
  *
- * Gets the user language from the locale.
+ * Gets the user language from the locale. This is the first component of the
+ * locale.
  *
- * Returns: the language string, e.g. "fr"
+ * Typically you should use the full locale rather than the language, as the
+ * same language can be used quite differently in different territories.
+ *
+ * Returns: the language string, e.g. `fr`
  *
  * Since: 3.22
  **/
@@ -838,6 +853,64 @@ gs_plugin_status_update (GsPlugin *plugin, GsApp *app, GsPluginStatus status)
 	g_source_attach (idle_source, NULL);
 }
 
+typedef struct {
+	GsPlugin	*plugin;
+	gchar		*remote;
+	gchar		*realm;
+	GCallback	 callback;
+	gpointer	 user_data;
+} GsPluginBasicAuthHelper;
+
+static gboolean
+gs_plugin_basic_auth_start_cb (gpointer user_data)
+{
+	GsPluginBasicAuthHelper *helper = user_data;
+	g_signal_emit (helper->plugin,
+		       signals[SIGNAL_BASIC_AUTH_START], 0,
+		       helper->remote,
+		       helper->realm,
+		       helper->callback,
+		       helper->user_data);
+	g_free (helper->remote);
+	g_free (helper->realm);
+	g_slice_free (GsPluginBasicAuthHelper, helper);
+	return FALSE;
+}
+
+/**
+ * gs_plugin_basic_auth_start:
+ * @plugin: a #GsPlugin
+ * @remote: a string
+ * @realm: a string
+ * @callback: callback to invoke to submit the user/password
+ * @user_data: callback data to pass to the callback
+ *
+ * Emit the basic-auth-start signal in the main thread.
+ *
+ * Since: 3.38
+ **/
+void
+gs_plugin_basic_auth_start (GsPlugin *plugin,
+                            const gchar *remote,
+                            const gchar *realm,
+                            GCallback callback,
+                            gpointer user_data)
+{
+	GsPluginBasicAuthHelper *helper;
+	g_autoptr(GSource) idle_source = NULL;
+
+	helper = g_slice_new0 (GsPluginBasicAuthHelper);
+	helper->plugin = plugin;
+	helper->remote = g_strdup (remote);
+	helper->realm = g_strdup (realm);
+	helper->callback = callback;
+	helper->user_data = user_data;
+
+	idle_source = g_idle_source_new ();
+	g_source_set_callback (idle_source, gs_plugin_basic_auth_start_cb, helper, NULL);
+	g_source_attach (idle_source, NULL);
+}
+
 static gboolean
 gs_plugin_app_launch_cb (gpointer user_data)
 {
@@ -1946,6 +2019,13 @@ gs_plugin_class_init (GsPluginClass *klass)
 			      G_STRUCT_OFFSET (GsPluginClass, allow_updates),
 			      NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
+
+	signals [SIGNAL_BASIC_AUTH_START] =
+		g_signal_new ("basic-auth-start",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GsPluginClass, basic_auth_start),
+			      NULL, NULL, g_cclosure_marshal_generic,
+			      G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_POINTER);
 }
 
 static void
