@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2013-2017 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2015-2018 Kalev Lember <klember@redhat.com>
@@ -1129,7 +1130,9 @@ gs_utils_get_memory_total (void)
 #if defined(__linux__)
 	struct sysinfo si = { 0 };
 	sysinfo (&si);
-	return si.totalram / MB_IN_BYTES / si.mem_unit;
+	if (si.mem_unit > 0)
+		return si.totalram / MB_IN_BYTES / si.mem_unit;
+	return 0;
 #elif defined(__FreeBSD__)
 	unsigned long physmem;
 	sysctl ((int[]){ CTL_HW, HW_PHYSMEM }, 2, &physmem, &(size_t){ sizeof (physmem) }, NULL, 0);
