@@ -1,27 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2013-2016 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2018 Kalev Lember <klember@redhat.com>
  *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0+
  */
 
-#ifndef __GS_UTILS_H
-#define __GS_UTILS_H
+#pragma once
 
 #include <gio/gdesktopappinfo.h>
 #include <gtk/gtk.h>
@@ -69,6 +55,9 @@ GPermission	*gs_utils_get_permission	(const gchar	*id,
 						 GError		**error);
 gboolean	 gs_utils_strv_fnmatch		(gchar		**strv,
 						 const gchar	*str);
+gchar           *gs_utils_sort_key		(const gchar    *str);
+gint             gs_utils_sort_strcmp		(const gchar    *str1,
+						 const gchar	*str2);
 GDesktopAppInfo *gs_utils_get_desktop_app_info	(const gchar	*id);
 gboolean	 gs_utils_rmtree		(const gchar	*directory,
 						 GError		**error);
@@ -89,7 +78,6 @@ gboolean	 gs_utils_error_convert_gdbus	(GError		**perror);
 gboolean	 gs_utils_error_convert_gdk_pixbuf(GError	**perror);
 gboolean	 gs_utils_error_convert_json_glib (GError	**perror);
 gboolean	 gs_utils_error_convert_appstream (GError	**perror);
-gboolean	 gs_utils_is_low_resolution	  (GtkWidget     *toplevel);
 
 gchar		*gs_utils_get_url_scheme	(const gchar	*url);
 gchar		*gs_utils_get_url_path		(const gchar	*url);
@@ -103,9 +91,6 @@ gboolean	 gs_utils_parse_evr		(const gchar	 *evr,
 						 gchar		**out_epoch,
 						 gchar		**out_version,
 						 gchar		**out_release);
+void		 gs_utils_set_online_updates_timestamp (GSettings *settings);
 
 G_END_DECLS
-
-#endif /* __GS_UTILS_H */
-
-/* vim: set noexpandtab: */
