@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2017 Richard Hughes <richard@hughsie.com>
  *
@@ -124,6 +125,7 @@ static gchar *
 gs_fwupd_release_get_name (FwupdRelease *release)
 {
 	const gchar *name = fwupd_release_get_name (release);
+#if FWUPD_CHECK_VERSION(1,2,7)
 	GPtrArray *cats = fwupd_release_get_categories (release);
 
 	for (guint i = 0; i < cats->len; i++) {
@@ -131,46 +133,57 @@ gs_fwupd_release_get_name (FwupdRelease *release)
 		if (g_strcmp0 (cat, "X-Device") == 0) {
 			/* TRANSLATORS: a specific part of hardware,
 			 * the first %s is the device name, e.g. 'Unifying Receiver` */
-			return g_strdup_printf (_("%s Device"), name);
+			return g_strdup_printf (_("%s Device Update"), name);
 		}
 		if (g_strcmp0 (cat, "X-System") == 0) {
 			/* TRANSLATORS: the entire system, e.g. all internal devices,
 			 * the first %s is the device name, e.g. 'ThinkPad P50` */
-			return g_strdup_printf (_("%s System"), name);
+			return g_strdup_printf (_("%s System Update"), name);
 		}
 		if (g_strcmp0 (cat, "X-EmbeddedController") == 0) {
 			/* TRANSLATORS: the EC is typically the keyboard controller chip,
 			 * the first %s is the device name, e.g. 'ThinkPad P50` */
-			return g_strdup_printf (_("%s Embedded Controller"), name);
+			return g_strdup_printf (_("%s Embedded Controller Update"), name);
 		}
 		if (g_strcmp0 (cat, "X-ManagementEngine") == 0) {
 			/* TRANSLATORS: ME stands for Management Engine, the Intel AMT thing,
 			 * the first %s is the device name, e.g. 'ThinkPad P50` */
-			return g_strdup_printf (_("%s ME"), name);
+			return g_strdup_printf (_("%s ME Update"), name);
 		}
 		if (g_strcmp0 (cat, "X-CorporateManagementEngine") == 0) {
 			/* TRANSLATORS: ME stands for Management Engine (with Intel AMT),
 			 * where the first %s is the device name, e.g. 'ThinkPad P50` */
-			return g_strdup_printf (_("%s Corporate ME"), name);
+			return g_strdup_printf (_("%s Corporate ME Update"), name);
 		}
 		if (g_strcmp0 (cat, "X-ConsumerManagementEngine") == 0) {
 			/* TRANSLATORS: ME stands for Management Engine, where
 			 * the first %s is the device name, e.g. 'ThinkPad P50` */
-			return g_strdup_printf (_("%s Consumer ME"), name);
+			return g_strdup_printf (_("%s Consumer ME Update"), name);
 		}
 		if (g_strcmp0 (cat, "X-Controller") == 0) {
 			/* TRANSLATORS: the controller is a device that has other devices
 			 * plugged into it, for example ThunderBolt, FireWire or USB,
 			 * the first %s is the device name, e.g. 'Intel ThunderBolt` */
-			return g_strdup_printf (_("%s Controller"), name);
+			return g_strdup_printf (_("%s Controller Update"), name);
 		}
 		if (g_strcmp0 (cat, "X-ThunderboltController") == 0) {
 			/* TRANSLATORS: the Thunderbolt controller is a device that
 			 * has other high speed Thunderbolt devices plugged into it;
 			 * the first %s is the system name, e.g. 'ThinkPad P50` */
-			return g_strdup_printf (_("%s Thunderbolt Controller"), name);
+			return g_strdup_printf (_("%s Thunderbolt Controller Update"), name);
+		}
+		if (g_strcmp0 (cat, "X-CpuMicrocode") == 0) {
+			/* TRANSLATORS: the CPU microcode is firmware loaded onto the CPU
+			 * at system bootup */
+			return g_strdup_printf (_("%s CPU Microcode Update"), name);
+		}
+		if (g_strcmp0 (cat, "X-Configuration") == 0) {
+			/* TRANSLATORS: configuration refers to hardware state,
+			 * e.g. a security database or a default power value */
+			return g_strdup_printf (_("%s Configuration Update"), name);
 		}
 	}
+#endif
 
 	/* default fallback */
 	return g_strdup (name);
@@ -223,7 +236,7 @@ gs_fwupd_app_set_from_release (GsApp *app, FwupdRelease *rel)
 		as_screenshot_add_image (ss, im);
 		if (fwupd_release_get_detach_caption (rel) != NULL)
 			as_screenshot_set_caption (ss, NULL, fwupd_release_get_detach_caption (rel));
-		gs_app_add_screenshot (app, ss);
+		gs_app_set_action_screenshot (app, ss);
 	}
 #endif
 }
