@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2015-2018 Canonical Ltd
  *
@@ -890,15 +891,15 @@ refine_screenshots (GsApp *app, SnapdSnap *snap)
 	}
 }
 
-gboolean
-gs_plugin_refine_app (GsPlugin *plugin,
-		      GsApp *app,
-		      GsPluginRefineFlags flags,
-		      GCancellable *cancellable,
-		      GError **error)
+static gboolean
+refine_app_with_client (GsPlugin             *plugin,
+			SnapdClient          *client,
+			GsApp                *app,
+			GsPluginRefineFlags   flags,
+			GCancellable         *cancellable,
+			GError              **error)
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
-	g_autoptr(SnapdClient) client = NULL;
 	const gchar *snap_name, *name, *version;
 	g_autofree gchar *channel = NULL;
 	g_autofree gchar *store_channel = NULL;
@@ -915,10 +916,6 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	if (g_strcmp0 (gs_app_get_management_plugin (app), "snap") != 0)
 		return TRUE;
 
-	client = get_client (plugin, error);
-	if (client == NULL)
-		return FALSE;
-
 	snap_name = gs_app_get_metadata_item (app, "snap::name");
 	channel = g_strdup (gs_app_get_branch (app));
 
@@ -1059,6 +1056,28 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	return TRUE;
 }
 
+gboolean
+gs_plugin_refine (GsPlugin             *plugin,
+		  GsAppList            *list,
+		  GsPluginRefineFlags   flags,
+		  GCancellable         *cancellable,
+		  GError              **error)
+{
+	g_autoptr(SnapdClient) client = NULL;
+
+	client = get_client (plugin, error);
+	if (client == NULL)
+		return FALSE;
+
+	for (guint i = 0; i < gs_app_list_length (list); i++) {
+		GsApp *app = gs_app_list_index (list, i);
+		if (!refine_app_with_client (plugin, client, app, flags, cancellable, error))
+			return FALSE;
+	}
+
+	return TRUE;
+}
+
 static void
 progress_cb (SnapdClient *client, SnapdChange *change, gpointer deprecated, gpointer user_data)
 {
