@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2012-2016 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2013 Matthias Clasen <mclasen@redhat.com>
@@ -45,7 +46,6 @@ typedef struct
 	gboolean	 show_update;
 	gboolean	 show_installed_size;
 	guint		 pending_refresh_id;
-	GSettings	*settings;
 } GsAppRowPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GsAppRow, gs_app_row, GTK_TYPE_LIST_BOX_ROW)
@@ -58,6 +58,15 @@ enum {
 
 static guint signals [SIGNAL_LAST] = { 0 };
 
+typedef enum {
+	PROP_APP = 1,
+	PROP_SHOW_SOURCE,
+	PROP_SHOW_BUTTONS,
+	PROP_SHOW_INSTALLED_SIZE,
+} GsAppRowProperty;
+
+static GParamSpec *obj_props[PROP_SHOW_INSTALLED_SIZE + 1] = { NULL, };
+
 /**
  * gs_app_row_get_description:
  *
@@ -228,8 +237,8 @@ gs_app_row_refresh_button (GsAppRow *app_row, gboolean missing_search_result)
 	}
 }
 
-void
-gs_app_row_refresh (GsAppRow *app_row)
+static void
+gs_app_row_actually_refresh (GsAppRow *app_row)
 {
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 	GtkStyleContext *context;
@@ -486,17 +495,6 @@ gs_app_row_unreveal (GsAppRow *app_row)
 	gtk_revealer_set_reveal_child (GTK_REVEALER (revealer), FALSE);
 }
 
-static void
-settings_changed_cb (GsAppRow *self,
-		     const gchar *key,
-		     gpointer data)
-{
-	if (g_strcmp0 (key, "show-nonfree-ui") == 0 ||
-	    g_strcmp0 (key, "show-folder-management") == 0) {
-		gs_app_row_refresh (self);
-	}
-}
-
 GsApp *
 gs_app_row_get_app (GsAppRow *app_row)
 {
@@ -511,8 +509,19 @@ gs_app_row_refresh_idle_cb (gpointer user_data)
 	GsAppRow *app_row = GS_APP_ROW (user_data);
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 	priv->pending_refresh_id = 0;
-	gs_app_row_refresh (app_row);
-	return FALSE;
+	gs_app_row_actually_refresh (app_row);
+	return G_SOURCE_REMOVE;
+}
+
+/* Schedule an idle call to gs_app_row_actually_refresh() unless one’s already pending. */
+static void
+gs_app_row_schedule_refresh (GsAppRow *app_row)
+{
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+
+	if (priv->pending_refresh_id > 0)
+		return;
+	priv->pending_refresh_id = g_idle_add (gs_app_row_refresh_idle_cb, app_row);
 }
 
 static void
@@ -520,10 +529,7 @@ gs_app_row_notify_props_changed_cb (GsApp *app,
 				    GParamSpec *pspec,
 				    GsAppRow *app_row)
 {
-	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
-	if (priv->pending_refresh_id > 0)
-		return;
-	priv->pending_refresh_id = g_idle_add (gs_app_row_refresh_idle_cb, app_row);
+	gs_app_row_schedule_refresh (app_row);
 }
 
 static void
@@ -545,7 +551,59 @@ gs_app_row_set_app (GsAppRow *app_row, GsApp *app)
 	g_signal_connect_object (priv->app, "notify::allow-cancel",
 				 G_CALLBACK (gs_app_row_notify_props_changed_cb),
 				 app_row, 0);
-	gs_app_row_refresh (app_row);
+
+	g_object_notify (G_OBJECT (app_row), "app");
+
+	gs_app_row_schedule_refresh (app_row);
+}
+
+static void
+gs_app_row_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+{
+	GsAppRow *app_row = GS_APP_ROW (object);
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+
+	switch (prop_id) {
+	case PROP_APP:
+		g_value_set_object (value, priv->app);
+		break;
+	case PROP_SHOW_SOURCE:
+		g_value_set_boolean (value, priv->show_source);
+		break;
+	case PROP_SHOW_BUTTONS:
+		g_value_set_boolean (value, priv->show_buttons);
+		break;
+	case PROP_SHOW_INSTALLED_SIZE:
+		g_value_set_boolean (value, priv->show_installed_size);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+gs_app_row_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+{
+	GsAppRow *app_row = GS_APP_ROW (object);
+
+	switch (prop_id) {
+	case PROP_APP:
+		gs_app_row_set_app (app_row, g_value_get_object (value));
+		break;
+	case PROP_SHOW_SOURCE:
+		gs_app_row_set_show_source (app_row, g_value_get_boolean (value));
+		break;
+	case PROP_SHOW_BUTTONS:
+		gs_app_row_set_show_buttons (app_row, g_value_get_boolean (value));
+		break;
+	case PROP_SHOW_INSTALLED_SIZE:
+		gs_app_row_set_show_installed_size (app_row, g_value_get_boolean (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
 }
 
 static void
@@ -554,8 +612,6 @@ gs_app_row_destroy (GtkWidget *object)
 	GsAppRow *app_row = GS_APP_ROW (object);
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
-	g_clear_object (&priv->settings);
-
 	if (priv->app)
 		g_signal_handlers_disconnect_by_func (priv->app, gs_app_row_notify_props_changed_cb, app_row);
 
@@ -574,8 +630,60 @@ gs_app_row_class_init (GsAppRowClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
+	object_class->get_property = gs_app_row_get_property;
+	object_class->set_property = gs_app_row_set_property;
 	widget_class->destroy = gs_app_row_destroy;
 
+	/**
+	 * GsAppRow:app:
+	 *
+	 * The #GsApp to show in this row.
+	 *
+	 * Since: 3.38
+	 */
+	obj_props[PROP_APP] =
+		g_param_spec_object ("app", NULL, NULL,
+				     GS_TYPE_APP,
+				     G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	/**
+	 * GsAppRow:show-source:
+	 *
+	 * Show the source of the app in the row.
+	 *
+	 * Since: 3.38
+	 */
+	obj_props[PROP_SHOW_SOURCE] =
+		g_param_spec_boolean ("show-source", NULL, NULL,
+				      FALSE,
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	/**
+	 * GsAppRow:show-buttons:
+	 *
+	 * Show buttons (such as Install, Cancel or Update) in the app row.
+	 *
+	 * Since: 3.38
+	 */
+	obj_props[PROP_SHOW_BUTTONS] =
+		g_param_spec_boolean ("show-buttons", NULL, NULL,
+				      FALSE,
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	/**
+	 * GsAppRow:show-installed-size:
+	 *
+	 * Show the installed size of the app in the row.
+	 *
+	 * Since: 3.38
+	 */
+	obj_props[PROP_SHOW_INSTALLED_SIZE] =
+		g_param_spec_boolean ("show-installed-size", NULL, NULL,
+				      FALSE,
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	g_object_class_install_properties (object_class, G_N_ELEMENTS (obj_props), obj_props);
+
 	signals [SIGNAL_BUTTON_CLICKED] =
 		g_signal_new ("button-clicked",
 			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
@@ -625,15 +733,9 @@ gs_app_row_init (GsAppRow *app_row)
 
 	gtk_widget_set_has_window (GTK_WIDGET (app_row), FALSE);
 	gtk_widget_init_template (GTK_WIDGET (app_row));
-	gs_star_widget_set_icon_size (GS_STAR_WIDGET (priv->star), 12);
-
-	priv->settings = g_settings_new ("org.gnome.software");
 
 	g_signal_connect (priv->button, "clicked",
 			  G_CALLBACK (button_clicked), app_row);
-	g_signal_connect_swapped (priv->settings, "changed",
-				  G_CALLBACK (settings_changed_cb),
-				  app_row);
 }
 
 void
@@ -657,7 +759,7 @@ gs_app_row_set_colorful (GsAppRow *app_row, gboolean colorful)
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
 	priv->colorful = colorful;
-	gs_app_row_refresh (app_row);
+	gs_app_row_schedule_refresh (app_row);
 }
 
 void
@@ -666,7 +768,8 @@ gs_app_row_set_show_buttons (GsAppRow *app_row, gboolean show_buttons)
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
 	priv->show_buttons = show_buttons;
-	gs_app_row_refresh (app_row);
+	g_object_notify (G_OBJECT (app_row), "show-buttons");
+	gs_app_row_schedule_refresh (app_row);
 }
 
 void
@@ -675,7 +778,7 @@ gs_app_row_set_show_rating (GsAppRow *app_row, gboolean show_rating)
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
 	priv->show_rating = show_rating;
-	gs_app_row_refresh (app_row);
+	gs_app_row_schedule_refresh (app_row);
 }
 
 void
@@ -684,7 +787,8 @@ gs_app_row_set_show_source (GsAppRow *app_row, gboolean show_source)
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
 	priv->show_source = show_source;
-	gs_app_row_refresh (app_row);
+	g_object_notify (G_OBJECT (app_row), "show-source");
+	gs_app_row_schedule_refresh (app_row);
 }
 
 void
@@ -692,7 +796,8 @@ gs_app_row_set_show_installed_size (GsAppRow *app_row, gboolean show_size)
 {
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 	priv->show_installed_size = show_size;
-	gs_app_row_refresh (app_row);
+	g_object_notify (G_OBJECT (app_row), "show-installed-size");
+	gs_app_row_schedule_refresh (app_row);
 }
 
 /**
@@ -706,17 +811,15 @@ gs_app_row_set_show_update (GsAppRow *app_row, gboolean show_update)
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
 	priv->show_update = show_update;
-	gs_app_row_refresh (app_row);
+	gs_app_row_schedule_refresh (app_row);
 }
 
 GtkWidget *
 gs_app_row_new (GsApp *app)
 {
-	GtkWidget *app_row;
-
 	g_return_val_if_fail (GS_IS_APP (app), NULL);
 
-	app_row = g_object_new (GS_TYPE_APP_ROW, NULL);
-	gs_app_row_set_app (GS_APP_ROW (app_row), app);
-	return app_row;
+	return g_object_new (GS_TYPE_APP_ROW,
+			     "app", app,
+			     NULL);
 }
