@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2012 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2014-2018 Kalev Lember <klember@redhat.com>
@@ -26,7 +27,6 @@ struct _GsAppRowClass
 };
 
 GtkWidget	*gs_app_row_new				(GsApp		*app);
-void		 gs_app_row_refresh			(GsAppRow	*app_row);
 void		 gs_app_row_unreveal			(GsAppRow	*app_row);
 void		 gs_app_row_set_colorful		(GsAppRow	*app_row,
 							 gboolean	 colorful);
