@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2013 Matthias Clasen <mclasen@redhat.com>
@@ -157,14 +158,8 @@ gs_category_page_get_apps_cb (GObject *source_object,
 		gtk_widget_set_can_focus (gtk_widget_get_parent (tile), FALSE);
 	}
 
-	self->sort_rating_handler_id = g_signal_connect (self->sort_rating_button,
-							 "clicked",
-							 G_CALLBACK (sort_button_clicked),
-							 self);
-	self->sort_name_handler_id = g_signal_connect (self->sort_name_button,
-						       "clicked",
-						       G_CALLBACK (sort_button_clicked),
-						       self);
+	g_signal_handler_unblock (self->sort_rating_button, self->sort_rating_handler_id);
+	g_signal_handler_unblock (self->sort_name_button, self->sort_name_handler_id);
 }
 
 static gboolean
@@ -321,17 +316,8 @@ gs_category_page_reload (GsPage *page)
 		gtk_widget_set_visible (self->subcats_sort_button, TRUE);
 	}
 
-	if (self->sort_rating_handler_id > 0) {
-		g_signal_handler_disconnect (self->sort_rating_button,
-					     self->sort_rating_handler_id);
-		self->sort_rating_handler_id = 0;
-	}
-
-	if (self->sort_name_handler_id > 0) {
-		g_signal_handler_disconnect (self->sort_name_button,
-					     self->sort_name_handler_id);
-		self->sort_name_handler_id = 0;
-	}
+	g_signal_handler_block (self->sort_rating_button, self->sort_rating_handler_id);
+	g_signal_handler_block (self->sort_name_button, self->sort_name_handler_id);
 
 	gs_container_remove_all (GTK_CONTAINER (self->category_detail_box));
 
@@ -516,6 +502,18 @@ gs_category_page_dispose (GObject *object)
 	g_cancellable_cancel (self->cancellable);
 	g_clear_object (&self->cancellable);
 
+	if (self->sort_rating_handler_id > 0) {
+		g_signal_handler_disconnect (self->sort_rating_button,
+					     self->sort_rating_handler_id);
+		self->sort_rating_handler_id = 0;
+	}
+
+	if (self->sort_name_handler_id > 0) {
+		g_signal_handler_disconnect (self->sort_name_button,
+					     self->sort_name_handler_id);
+		self->sort_name_handler_id = 0;
+	}
+
 	g_clear_object (&self->builder);
 	g_clear_object (&self->category);
 	g_clear_object (&self->subcategory);
@@ -543,6 +541,15 @@ gs_category_page_setup (GsPage *page,
 				    gs_category_page_sort_flow_box_sort_func,
 				    self, NULL);
 
+	self->sort_rating_handler_id = g_signal_connect (self->sort_rating_button,
+							 "clicked",
+							 G_CALLBACK (sort_button_clicked),
+							 self);
+	self->sort_name_handler_id = g_signal_connect (self->sort_name_button,
+						       "clicked",
+						       G_CALLBACK (sort_button_clicked),
+						       self);
+
 	adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (self->scrolledwindow_category));
 	gtk_container_set_focus_vadjustment (GTK_CONTAINER (self->category_detail_box), adj);
 	return TRUE;
