@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ * vi:set noexpandtab tabstop=8 shiftwidth=8:
  *
  * Copyright (C) 2013 Matthias Clasen <mclasen@redhat.com>
  * Copyright (C) 2019 Richard Hughes <richard@hughsie.com>
@@ -22,6 +23,7 @@ struct _GsSummaryTile
 	GtkWidget	*eventbox;
 	GtkWidget	*stack;
 	gint		 preferred_width;
+	GtkCssProvider	*tile_provider;  /* (owned) (nullable) */
 };
 
 G_DEFINE_TYPE (GsSummaryTile, gs_summary_tile, GS_TYPE_APP_TILE)
@@ -41,7 +43,7 @@ gs_summary_tile_refresh (GsAppTile *self)
 	const GdkPixbuf *pixbuf;
 	gboolean installed;
 	g_autofree gchar *name = NULL;
-	g_autofree gchar *summary = NULL;
+	const gchar *summary;
 	const gchar *css;
 
 	if (app == NULL)
@@ -53,18 +55,7 @@ gs_summary_tile_refresh (GsAppTile *self)
 	/* set name */
 	gtk_label_set_label (GTK_LABEL (tile->name), gs_app_get_name (app));
 
-	/* some kinds have boring summaries */
-	switch (gs_app_get_kind (app)) {
-	case AS_APP_KIND_SHELL_EXTENSION:
-		summary = g_strdup (gs_app_get_description (app));
-		if (summary != NULL)
-			g_strdelimit (summary, "\n\t", ' ');
-		break;
-	default:
-		summary = g_strdup (gs_app_get_summary (app));
-		break;
-	}
-
+	summary = gs_app_get_summary (app);
 	gtk_label_set_label (GTK_LABEL (tile->summary), summary);
 	gtk_widget_set_visible (tile->summary, summary && summary[0]);
 
@@ -84,7 +75,7 @@ gs_summary_tile_refresh (GsAppTile *self)
 
 	/* perhaps set custom css */
 	css = gs_app_get_metadata_item (app, "GnomeSoftware::AppTile-css");
-	gs_utils_widget_set_css (GTK_WIDGET (tile), "summary-tile", css);
+	gs_utils_widget_set_css (GTK_WIDGET (tile), &tile->tile_provider, "summary-tile", css);
 
 	accessible = gtk_widget_get_accessible (GTK_WIDGET (tile));
 
@@ -168,6 +159,16 @@ gs_summary_tile_set_property (GObject *object,
 	}
 }
 
+static void
+gs_summary_tile_dispose (GObject *object)
+{
+	GsSummaryTile *tile = GS_SUMMARY_TILE (object);
+
+	g_clear_object (&tile->tile_provider);
+
+	G_OBJECT_CLASS (gs_summary_tile_parent_class)->dispose (object);
+}
+
 static void
 gs_app_get_preferred_width (GtkWidget *widget,
 			    gint *min, gint *nat)
@@ -198,6 +199,7 @@ gs_summary_tile_class_init (GsSummaryTileClass *klass)
 
 	object_class->get_property = gs_summary_tile_get_property;
 	object_class->set_property = gs_summary_tile_set_property;
+	object_class->dispose = gs_summary_tile_dispose;
 
 	widget_class->get_preferred_width = gs_app_get_preferred_width;
 
